% Written by Yongquan and Huixin
% August 2022
% The main file to run simulations in different scenarios in the BCD 2022 paper. 


clear all;
current_path = pwd;

% addpath '//Your/dynare/matlab'


%%
% plot the baseline with credit shock (figure 4):
%   choose index_baseline = 1, rho_bo =0.8, index_eo=1
% plot cases of credit shock with different persistence (figure 5):
%   choose index_baseline = 1, rho_bo = 0.5 / 0.95 (run two times)
% plot cases with credit rules:
%   choose index_baseline = 2, index_persistrule
% plot the baseline with different fiscal instruments (figure 9)
%   choose index_baseline = 1, rho_bo =0.8, index_ei/ec/eo=1
% plot the fiscal multiplier (figure 10) 
%   choose index_compute_Mult = 1

% choose credit shock or credit rule
index_baseline = 1;     % 1: baseline model with credit shocks & different persistence
                        % 2: alternative model with credit rules
                        % 3: baseline model with credit shocks & fiscal instruments
                        
% if index_baseline == 1, choose different shock persistence                  
rho_bo = 0.8;           % 0.5 or 0.95 [baseline 0.8]
                        
% if index_baseline == 2, then choose different types of credit rule
index_persistrule = 0;  % 0: baseline (rho_s = 0, rho_y = 0)
                        % 1: bailout rule (rho_s = 0, rho_y >0)
                        % 2: persistent bailout rule with rho_s > 0, rho_y >0

% choose whether to compute multiplier
index_compute_Mult = 1;

% choose which shock for IRFs
index_ei = 1;
index_eio = 0;
index_ec = 1;
index_eo = 1;
index_ebeta = 0;

% choose whether to save chart
index_plot_save = 1;
index_small_panel = 0;      % plot small panel chart


%%
% simulations
cd ./dynare_code
% baseline model with different credit shock persistence
if index_baseline == 1
    if rho_bo == 0.8
%         dynare norule.mod
        dynare model.mod
    elseif rho_bo == 0.5
        dynare norule_rhobo05.mod
    elseif rho_bo == 0.95
        dynare norule_rhobo095.mod
    end
% alternative model with different credit rules
elseif index_baseline == 2
    if index_persistrule ==0
        dynare norule.mod
    elseif index_persistrule == 1
        dynare rule.mod
    elseif index_persistrule == 2
        dynare persistrule.mod
    end
elseif index_baseline == 3
    dynare model.mod
end
irf_EME = oo_.irfs;
cd ..

% load steady-state values
var_list_mod = {'Bailout','GI','C','Y','I','WG','Wp','R','T','L','Lp','LG','PG','Kp',...
    'KG','GC','Ap','At','N','B','RB','omega','z','fo','fo1','go','go1','do',...
    'bo','ppi','YF','x','gcshock','gishock','boshock','betashock','qk','tau','Y_output','YG','beta'};

var = strcat(var_list_mod,'_ss');
for ii = 1:length(var_list_mod)
    eval([char(var(ii)) '= oo_.steady_state(ii);'])
end

%%
% plot IRFs
steps = 40;
if index_baseline == 1
    subplot_loop_diffRho
    
elseif index_baseline ==2
    if index_persistrule ==0
        linecolor = 'k--';
    elseif index_persistrule == 1
        linecolor = 'b';
    elseif index_persistrule == 2
        linecolor = 'r:';
    end
    
    subplot_loop_ebeta
    
elseif index_baseline == 3
    subplot_loop
end


%%
% compute multiplier
if index_compute_Mult == 1
    horizon = 80;
    MultB = zeros(horizon,1);
    MultGI = zeros(horizon,1);
    MultGC = zeros(horizon,1);
    MultBeta = zeros(horizon,1);
    for ii = 1:horizon
        MultB(ii) = PVBmultiplier(RB_ss,irf_EME,ii);
        MultGI(ii) = PVGImultiplier(RB_ss,irf_EME,ii);
        MultGC(ii) = PVGCmultiplier(RB_ss,irf_EME,ii);
    end
    figure(3);
    plot(MultB,'b', 'LineWidth', 2); hold on;
    plot(MultGI,'k-.', 'LineWidth', 2); hold on;
    plot(MultGC,'r:', 'LineWidth', 2); hold on;
    legend('Credit','Govt investment','Govt consumption')  
    legend('location','southeast')
end


%% Save graphs
if index_plot_save ==1
    if index_baseline == 1
        figure(2)
        set(gcf,'PaperPositionMode','manual')
        set(gcf,'PaperUnits','inches','PaperPosition',[0 -1 9 12])
        % left, bottom, horitonzal length, vertial length   
        print -depsc eo_rhobo.eps
    end
    if index_compute_mult == 1
        figure(3)
        set(gcf,'PaperPositionMode','manual')
        set(gcf,'PaperUnits','inches','PaperPosition',[0 -1 9 8])
        % left, bottom, horitonzal length, vertial length   
        print -depsc mult_gc_gi_sb.eps
    end
    if index_baseline == 3
        set(gcf,'PaperPositionMode','manual')
        set(gcf,'PaperUnits','inches','PaperPosition',[0 -1 9 12])
        % left, bottom, horitonzal length, vertial length   
        print -depsc ec_ei_eo.eps
    end
end


